pub struct HolderAuthorizationRequest {
pub subject_pubkey: SubjectPubkey,
}Expand description
Request for a holder authorization.
An auxiliary subject key asks to act under the holder’s identity. The holder chooses which credential to authorize separately when signing.
Fields
subject_pubkey: SubjectPubkeyThe auxiliary key or actor that the holder authorizes.
Implementations
Sourceimpl HolderAuthorizationRequest
impl HolderAuthorizationRequest
Sourcepub fn into_statement(
self,
holder_id_pubkey: HolderId,
issued_at: Timestamp,
credential: &SignedCredential,
) -> Result<HolderAuthorizationStatement, CredentialsError>
pub fn into_statement( self, holder_id_pubkey: HolderId, issued_at: Timestamp, credential: &SignedCredential, ) -> Result<HolderAuthorizationStatement, CredentialsError>
Convert this application input into the canonical statement to sign.