pub struct HolderAuthorizationStatement {
pub holder_id_pubkey: HolderId,
pub subject_pubkey: SubjectPubkey,
pub credential_digest: CredentialDigest,
pub issued_at: Timestamp,
}Expand description
Unsigned statement authorizing an auxiliary public key to present credentials.
Fields
holder_id_pubkey: HolderIdThe holder making the authorization.
subject_pubkey: SubjectPubkeyThe auxiliary key or actor that the holder authorizes.
credential_digest: CredentialDigestCredential digest this authorization grants the subject permission to present.
issued_at: TimestampUnix timestamp in seconds.
Implementations
Sourceimpl HolderAuthorizationStatement
impl HolderAuthorizationStatement
Sourcepub fn digest(&self) -> Result<Output<Sha256>, CredentialsError>
pub fn digest(&self) -> Result<Output<Sha256>, CredentialsError>
Compute the signature digest for this holder authorization statement.