pub struct SubjectPubkey(pub PublicKey);Expand description
Public identity of the auxiliary key or actor authorized by the holder.
V1 keeps this as a Nostr public key, matching IssuerId and HolderId.
Tuple Fields
0: PublicKeyTrait Implementations
Sourceimpl Clone for SubjectPubkey
impl Clone for SubjectPubkey
Sourcefn clone(&self) -> SubjectPubkey
fn clone(&self) -> SubjectPubkey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubjectPubkey
impl Debug for SubjectPubkey
Sourceimpl<'de> Deserialize<'de> for SubjectPubkey
impl<'de> Deserialize<'de> for SubjectPubkey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromStr for SubjectPubkey
impl FromStr for SubjectPubkey
Sourceimpl Hash for SubjectPubkey
impl Hash for SubjectPubkey
Sourceimpl Ord for SubjectPubkey
impl Ord for SubjectPubkey
Sourcefn cmp(&self, other: &SubjectPubkey) -> Ordering
fn cmp(&self, other: &SubjectPubkey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SubjectPubkey
impl PartialEq for SubjectPubkey
Sourceimpl PartialOrd for SubjectPubkey
impl PartialOrd for SubjectPubkey
Sourceimpl Serialize for SubjectPubkey
impl Serialize for SubjectPubkey
impl Eq for SubjectPubkey
impl StructuralPartialEq for SubjectPubkey