pub struct PendingIssuance {
pub version: ProtocolV1,
pub issuer_id: IssuerId,
pub info: Value,
pub blind_msg: Value,
/* private fields */
}Expand description
Holder-side pending issuance state.
Fields
version: ProtocolV1issuer_id: IssuerIdinfo: Valueblind_msg: ValueImplementations
Sourceimpl PendingIssuance
impl PendingIssuance
Sourcepub fn create_request(
issuer_public_key: &PbrsaPublicKey,
issuer_id: IssuerId,
info: Value,
blind_msg: Value,
) -> Result<(IssuanceRequest, Self), CredentialsError>
pub fn create_request( issuer_public_key: &PbrsaPublicKey, issuer_id: IssuerId, info: Value, blind_msg: Value, ) -> Result<(IssuanceRequest, Self), CredentialsError>
Create a holder issuance request and local pending state.
Sourcepub fn export_state(&self) -> Result<String, CredentialsError>
pub fn export_state(&self) -> Result<String, CredentialsError>
Export app-storable holder-side pending issuance state.
The exported state is sensitive issuance material. It is needed to finalize one issuer response after a process or browser reload.
Sourcepub fn import_state(state: &str) -> Result<Self, CredentialsError>
pub fn import_state(state: &str) -> Result<Self, CredentialsError>
Import app-stored holder-side pending issuance state.
Sourcepub fn finalize(
self,
issuer_public_key: &PbrsaPublicKey,
response: &IssuanceResponse,
) -> Result<SignedCredential, CredentialsError>
pub fn finalize( self, issuer_public_key: &PbrsaPublicKey, response: &IssuanceResponse, ) -> Result<SignedCredential, CredentialsError>
Finalize an issuer response into a holder credential.