pub struct IssuerAuthority {
pub version: ProtocolV1,
pub issuer: Issuer,
pub proof: SchnorrSignatureProof,
}Expand description
Signed issuer metadata used by verifiers before accepting credentials.
Fields
version: ProtocolV1issuer: Issuerproof: SchnorrSignatureProofImplementations
Sourceimpl IssuerAuthority
impl IssuerAuthority
Sourcepub fn digest(&self) -> Result<Output<Sha256>, CredentialsError>
pub fn digest(&self) -> Result<Output<Sha256>, CredentialsError>
Compute the signature digest for this issuer authority payload.
Sourcepub fn verify(&self) -> Result<Issuer, CredentialsError>
pub fn verify(&self) -> Result<Issuer, CredentialsError>
Verify this issuer authority’s identity signature and return the issuer metadata.