pub struct SignedCredential {
pub version: ProtocolV1,
pub credential: Credential,
pub proof: CredentialProof,
}Expand description
Final holder credential.
info is the JSON value visible to the issuer during issuance.
blind_msg is the JSON value hidden from the issuer while signing and
disclosed in the final credential. For the current Fedi/Nostr use case this
will likely contain a Nostr holder public key, but that is application data,
not a protocol-level field.
The credential revocation digest is computed over the canonical credential payload, excluding the proof.
Fields
version: ProtocolV1credential: Credentialproof: CredentialProofTrait Implementations
Sourceimpl Clone for SignedCredential
impl Clone for SignedCredential
Sourcefn clone(&self) -> SignedCredential
fn clone(&self) -> SignedCredential
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SignedCredential
impl Debug for SignedCredential
Sourceimpl<'de> Deserialize<'de> for SignedCredential
impl<'de> Deserialize<'de> for SignedCredential
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SignedCredential
impl PartialEq for SignedCredential
Sourceimpl Serialize for SignedCredential
impl Serialize for SignedCredential
impl StructuralPartialEq for SignedCredential