pub struct VerificationContext { /* private fields */ }Expand description
Stateful verifier for trusted issuers, revocations, and credentials.
Implementations
Sourceimpl VerificationContext
impl VerificationContext
Verify and trust an issuer authority for subsequent credential checks.
Sourcepub fn add_revocation(
&mut self,
signed_revocation: &SignedRevocation,
) -> Result<(), CredentialsError>
pub fn add_revocation( &mut self, signed_revocation: &SignedRevocation, ) -> Result<(), CredentialsError>
Verify and store a signed revocation from a trusted issuer.
Sourcepub fn verify_credential(
&self,
credential: &SignedCredential,
) -> Result<(), CredentialsError>
pub fn verify_credential( &self, credential: &SignedCredential, ) -> Result<(), CredentialsError>
Verify a finalized credential against trusted issuers and revocations.
Verify a credential and a holder authorization.
The SDK verifies signatures, issuer trust, credential revocation state,
credential binding, holder binding, and the authorization issued-at time.
Application policy still owns live proof that the caller controls
authorization.authorization.subject_pubkey.
Verify a credential and holder authorization using an explicit timestamp.